<?php
/**
 * amp functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package amp
 */

if ( ! function_exists( 'amp_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function amp_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on amp, use a find and replace
		 * to change 'amp' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'amp', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */

		// Register Navs
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'amp' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'amp_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;

add_action( 'after_setup_theme', 'amp_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function amp_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'amp_content_width', 640 );
}
add_action( 'after_setup_theme', 'amp_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function amp_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'amp' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'amp' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'amp_widgets_init' );

add_theme_support( 'post-thumbnails' );
/**
 * Enqueue scripts and styles.
 */
function amp_scripts() {
	wp_enqueue_style( 'amp-style', get_stylesheet_uri() );

	wp_enqueue_script( 'amp-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );

	wp_enqueue_script( 'amp-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'amp_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/*==============================================
=                    CUSTOM                    =
==============================================*/

// Custom Shortcodes
include('custom-shortcodes.php');

// ACF
if( function_exists('acf_add_options_page') ) {

	// Options Page
	acf_add_options_page(array(
		'page_title' 	=> 'Theme Settings',
		'menu_title'	=> 'Theme Settings',
		'menu_slug' 	=> 'theme_settings',
		'capability'	=> 'edit_posts',
		'redirect'		=> false
	));

	// CUSTOM POST TYPE FUNCTION
	function create_post_type() {
		if(get_field('module_awards', 'option')):
			register_post_type( 'awards',
				array(
					'exclude_from_search' => true,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('awards_name_plural','option'),
						'singular_name' => get_field('awards_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/awards.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('awards_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 'author', 'revisions', 'thumbnail'),
					'taxonomies'  => array('category'),
                    'show_in_rest' => true,
				)
			);
			register_taxonomy(
				'awards-tags',
				'awards',
				array(
					'label' => __( 'Tags' ),
					'rewrite' => array( 'slug' => 'awards-tags' ),
					'hierarchical' => true,
				)
			);
			if(get_field('awards_single_disable', 'option')):
				add_action( 'template_redirect', 'awards_single_redirect' );

				function awards_single_redirect() {
					if ( is_singular( 'awards' ) ) {
						wp_redirect( get_post_type_archive_link('awards') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_contact', 'option')):
			register_post_type( 'contact',
				array(
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('contact_name_plural','option'),
						'singular_name' => get_field('contact_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/contact.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('contact_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'show_in_nav_menus'	=> 'true',
					'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'revisions'),
					'taxonomies'  => array( 'category' ),
                    
				)
			);
			if(get_field('contact_single_disable', 'option')):
				add_action( 'template_redirect', 'contact_single_redirect' );

				function contact_single_redirect() {
					if ( is_singular( 'contact' ) ) {
						wp_redirect( get_post_type_archive_link('contact') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_faqs', 'option')):
			register_post_type( 'faqs',
				array(
					'exclude_from_search' => true,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('faqs_name_plural','option'),
						'singular_name' => get_field('faqs_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/faqs.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('faqs_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 'author', 'revisions'),
					'taxonomies'  => array('category'),
                    
				)
			);
			register_taxonomy(
				'faq',
				'faqs',
				array(
					'label' => __( 'Tags' ),
					'rewrite' => array( 'slug' => get_field('faqs_slug','option') ),
					'hierarchical' => true,
				)
			);
			if(get_field('faqs_single_disable', 'option')):
				add_action( 'template_redirect', 'faqs_single_redirect' );

				function faqs_single_redirect() {
					if ( is_singular( 'faqs' ) ) {
						wp_redirect( get_post_type_archive_link('faqs') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_jobs', 'option')):
			register_post_type( 'jobs',
				array(
					'exclude_from_search' => false,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('jobs_name_plural','option'),
						'singular_name' => get_field('jobs_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/jobs.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('jobs_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 
					'editor', 'author', 'revisions'),
                    
				)
			);
			if(get_field('jobs_single_disable', 'option')):
				add_action( 'template_redirect', 'jobs_single_redirect' );

				function jobs_single_redirect() {
					if ( is_singular( 'jobs' ) ) {
						wp_redirect( get_post_type_archive_link('jobs') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_press', 'option')):
			register_post_type( 'press',
				array(
					'exclude_from_search' => true,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('press_name_plural','option'),
						'singular_name' => get_field('press_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/press.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('press_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'revisions'),
					'taxonomies'  => array( 'category' ),
                    
				)
			);
			if(get_field('press_single_disable', 'option')):
				add_action( 'template_redirect', 'press_single_redirect' );

				function press_single_redirect() {
					if ( is_singular( 'press' ) ) {
						wp_redirect( get_post_type_archive_link('press') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_projects', 'option')):
			register_post_type( 'projects',
				array(
					'exclude_from_search' => false,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('projects_name_plural','option'),
						'singular_name' => get_field('projects_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/projects.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('projects_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'revisions'),
					'taxonomies'  => array( 'category' ),
				)
			);
			if(get_field('projects_single_disable', 'option')):
				add_action( 'template_redirect', 'projects_single_redirect' );

				function projects_single_redirect() {
					if ( is_singular( 'projects' ) ) {
						wp_redirect( get_post_type_archive_link('projects') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_services', 'option')):
			register_post_type( 'services',
				array(
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('services_name_plural','option'),
						'singular_name' => get_field('services_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/services.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('services_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'show_in_nav_menus'	=> 'true',
					'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'revisions'),
					'taxonomies'  => array( 'category' ),
                    
				)
			);
			if(get_field('services_single_disable', 'option')):
				add_action( 'template_redirect', 'services_single_redirect' );

				function services_single_redirect() {
					if ( is_singular( 'services' ) ) {
						wp_redirect( get_post_type_archive_link('services') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_team', 'option')):
			register_post_type( 'team',
				array(
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('team_name_plural','option'),
						'singular_name' => get_field('team_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/team.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('team_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'show_in_nav_menus'	=> 'true',
					'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'revisions', 'page-attributes'),
                    
				)
			);
			register_taxonomy(
				'team',
				'team',
				array(
					'label' => __( 'Teams' ),
					'rewrite' => array( 'slug' => get_field('team_slug','option') ),
					'hierarchical' => true,
				)
			);
			if(get_field('team_single_disable', 'option')):
				add_action( 'template_redirect', 'team_single_redirect' );

				function team_single_redirect() {
					if ( is_singular( 'team' ) ) {
						wp_redirect( get_post_type_archive_link('team') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if(get_field('module_testimonials', 'option')):
			register_post_type( 'testimonials',
				array(
					'exclude_from_search' => true,
					'has_archive' => true,
					'hierarchical' => true,
					'labels' => array(
						'name' => get_field('testimonials_name_plural','option'),
						'singular_name' => get_field('testimonials_name_singular','option'),
					),
					'menu_icon' => get_template_directory_uri() . '/inc/img/testimonials.png',
					'public' => true,
					'publicly_queryable'  => true,
					'rewrite' => array('slug' => get_field('testimonials_slug','option'), 'with_front' => true),
					'show_in_menu' => true,
					'supports' => array( 'title', 'author', 'revisions', 'thumbnail'),
					'taxonomies'  => array('category'),
                    
				)
			);
			register_taxonomy(
				'testimonial',
				'testimonials',
				array(
					'label' => __( 'Tags' ),
					'rewrite' => array( 'slug' => get_field('testimonials_slug','option') ),
					'hierarchical' => true,
				)
			);
			if(get_field('testimonials_single_disable', 'option')):
				add_action( 'template_redirect', 'testimonials_single_redirect' );

				function testimonials_single_redirect() {
					if ( is_singular( 'testimonials' ) ) {
						wp_redirect( get_post_type_archive_link('testimonials') . '#' . get_post_field( 'post_name', get_post() ), 301 );
						exit;
					}
				}
			endif;
		endif;
		if( have_rows('custom-post-type', 'option') ):
			while( have_rows('custom-post-type', 'option') ): the_row();
				register_post_type( get_sub_field('postType'),
					array(
						'labels' => array(
							'name' => get_sub_field('name'),
							'singular_name' => get_sub_field('_name_singular'),
						),
						'public' => true,
						'publicly_queryable'  => false,
						'has_archive' => false,
						'rewrite' => array('slug' => get_sub_field('slug')),
						'with_front' => false,
						'menu_icon' => get_sub_field('menuIcon'),
                        'show_in_rest' => true,
                        'supports' => array('editor')
					)
				);
			endwhile;
		endif;
		// // Exclude Multiple Content Types From Yoast SEO Sitemap
		// add_filter( 'wpseo_sitemap_exclude_post_type', 'sitemap_exclude_post_type', 10, 2 );
		// function sitemap_exclude_post_type( $value, $post_type ) {
		// 	$post_type_to_exclude = array('testimonials','faqs', 'results', 'awards');
		// 	if( in_array( $post_type, $post_type_to_exclude ) ) return true;
		// }
	}
		
	// Hooking up our function to theme setup
	add_action( 'init', 'create_post_type' );

	// ADD TEAM TAXONOMY TO JOBS CUSTOM POST TYPE
	function news_reg_tag() {
		register_taxonomy_for_object_type('team', 'jobs');
	}
	add_action('init', 'news_reg_tag');
	
	// HIDE BLOG POSTS	               
	$moduleBlog = get_field('module_blog', 'option');
	function remove_posts_menu() {
		remove_menu_page('edit.php');
	}
	if (!$moduleBlog) {
		add_action('admin_menu', 'remove_posts_menu');
	};
}
	// Rewrite permalinks on Options Page visit
	if (strpos($_SERVER['REQUEST_URI'], "theme_settings") !== false){
		flush_rewrite_rules();
	}



// Custom Image Sizes
add_action( 'after_setup_theme', 'wpdocs_theme_setup' );
function wpdocs_theme_setup() {
    add_image_size( 'header-banner', 1280, 720, array('center', 'center') ); // (cropped center center)
	add_image_size( 'card-post', 500, 281, array('center', 'center') ); // (cropped center center)
	add_image_size( 'card-horizontal-post', 450, 253, array('center', 'center') ); // (cropped center center)
	add_image_size( 'post-thumbnail', 300, 300, true );
}

// TGM Plugin Activation
require_once get_template_directory(). '/inc/plugins/class-tgm-plugin-activation.php';
require_once get_template_directory(). '/inc/plugins/tgm-plugin-activation.php';

// Admin CSS
function admin_style() {
	wp_enqueue_style('admin-styles', get_template_directory_uri().'/admin.css');
  }
  add_action('admin_enqueue_scripts', 'admin_style');

// Add Default Image Setting to Image Field
add_action('acf/render_field_settings/type=image',
           'add_default_value_to_image_field', 20);
function add_default_value_to_image_field($field) {
  $args = array(
    'label' => 'Default Image',
    'instructions' => 'Appears when creating a new post',
    'type' => 'image',
    'name' => 'default_value'
  );
  acf_render_field_setting($field, $args);
}
// Enqueue WP Media Scripts on ACF Field Group Edit Page
add_action('admin_enqueue_scripts', 'enqueue_uploader_for_image_default');
function enqueue_uploader_for_image_default() {
  $screen = get_current_screen();
  if ($screen && $screen->id && ($screen->id == 'acf-field-group')) {
    acf_enqueue_uploader();
  }
}
// Reset Default Image
add_filter('acf/load_value/type=image', 'reset_default_image', 10, 3);
function reset_default_image($value, $post_id, $field) {
  if (!$value) {
    $value = $field['default_value'];
  }
  return $value;
}
// Remove Admin Bar
add_filter('show_admin_bar', '__return_false');

// Remove wp emoji
remove_action('wp_head', 'print_emoji_detection_script', 7);
remove_action('wp_print_styles', 'print_emoji_styles');

remove_action( 'admin_print_scripts', 'print_emoji_detection_script' );
remove_action( 'admin_print_styles', 'print_emoji_styles' );

// Remove Dashicon
add_action( 'wp_print_styles',     'my_deregister_styles', 100 );

// Remove Styles
function my_deregister_styles()    {
	wp_deregister_style( 'dashicons' );
	wp_dequeue_style('dashicons');
	wp_deregister_style('wp-block-library');
	wp_dequeue_style( 'wp-block-library' );
	wp_deregister_style('amp-style');
	wp_dequeue_style('amp-style');
	wp_deregister_style('widgetopts-styles');
	wp_dequeue_style('widgetopts-styles');
	wp_deregister_style('wp-custom');
	wp_dequeue_style('wp-custom');
}
add_action( 'wp_print_styles', 'my_deregister_styles', 100 );
	
// Sidebar
function wpb_list_child_pages() {
	global $post;
	$args = array(
		'post_type'      => 'page',
		'posts_per_page' => -1,
		'post_parent'    => $post->ID,
		'order'          => 'ASC',
		'orderby'        => 'menu_order'
	 );
	$parent = new WP_Query( $args );
     // Bail if this is not a page.
	if ( ! is_page() ) {
       return false;
 	}
 		if ( is_page() && $parent->have_posts() ){
 		// Globalize the $post variable;
 		// probably already available in this context, but just in case...
 		echo '<div class="widget">';
 	?>
 	<h3 class="widget-title"><?php the_title(); ?></h3>
 <?php
 		echo '<nav class="sidebar-nav"><ul>';
 		global $post;
 		wp_list_pages( array(
 				// Only pages that are children of the current page's parent
 				'child_of' => $post->ID,
 				// Only show two level of hierarchy
 				'depth' => 1,
 				'title_li' => '',
 		) );
 		echo '</ul></nav></div>';
 	}
 }

/**
 * Register Custom Navigation Walker
 */
function register_navwalker(){
	require_once get_template_directory() . '/navwalker.php';
}
add_action( 'after_setup_theme', 'register_navwalker' );

function register_navwalker_mobile(){
	require_once get_template_directory() . '/navwalker-mobile.php';
}
add_action( 'after_setup_theme', 'register_navwalker_mobile' );

// Pagination
if ( ! function_exists( 'amp_theme_pagination' ) ) :

function amp_theme_pagination($the_query){
    $big = 999999999; // need an unlikely integer

    echo paginate_links( array(
        'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
        'format' => '?paged=%#%',
        'end_size' => 1,
		'mid_size' => 1,
        'current' => max( 1, get_query_var('paged') ),
        'total' => $the_query->max_num_pages,
    ) );
}

endif;

/* GET URL OF PAGE USING TEMPLATE */
function get_template_page_url($TEMPLATE_NAME){
    $url = null;
    $pages = get_pages(array(
        'meta_key' => '_wp_page_template',
        'meta_value' => $TEMPLATE_NAME
    ));
    if(isset($pages[0])) {
        $url = get_page_link($pages[0]->ID);
    }
    return $url;
}

/*==============================================
=           		WPFORMS	               =
==============================================*/
function wpf_dev_math_captcha_settings( $settings ) {
   
    /* Default settings
        array(
            'min' => 1,
            'max' => 15,
            'cal' => array( '+', '*' ),
        );
     */
 
    // Change max number 4 for easier math
    $settings['max'] = 4;
    $settings['cal'] = '+';
 
    return $settings;
 }
 add_filter( 'wpforms_math_captcha', 'wpf_dev_math_captcha_settings' );

/*==============================================
=           		LOGIN PAGE	               =
==============================================*/
 /* Change Login Logo */
if( class_exists('ACF') ) {
	$logo = get_field('logo', 'option');
	function my_login_logo_one() { 
		$logo = get_field('logo', 'option');
		?> 
		<style type="text/css"> 
		body.login div#login h1 a {
			background-image: url(<?php echo esc_url($logo['url']); ?>); 
			background-size: contain;
			width: 100%;
		} 
		</style>
		<?php 
		} add_action( 'login_enqueue_scripts', 'my_login_logo_one' );
}
// Change url of login logo link
add_filter( 'login_headerurl', 'custom_loginlogo_url');
function custom_loginlogo_url($url) {
return site_url();
}

/* Change the Redirect URL */
function admin_login_redirect( $redirect_to, $request, $user ) {
   global $user;
   
   if( isset( $user->roles ) && is_array( $user->roles ) ) {
      if( in_array( "administrator", $user->roles ) ) {
      return $redirect_to;
      } 
      else {
      return home_url();
      }
   }
   else {
   return $redirect_to;
   }
}

/* Set Remember Me To Checked */
function login_checked_remember_me() {
	add_filter( 'login_footer', 'rememberme_checked' );
	}
	add_action( 'init', 'login_checked_remember_me' );
	
	function rememberme_checked() {
	echo "<script>document.getElementById('rememberme').checked = true;</script>";
	}

add_filter("login_redirect", "admin_login_redirect", 10, 3);

/*==============================================
=          ADD FONT AWESOME TO BACKEND	       =
==============================================*/
function fontawesome_dashboard() {
	wp_enqueue_style('fontawesome', 'https://use.fontawesome.com/releases/v5.8.1/css/all.css', '', '5.8.1', 'all');
 }
 
 add_action('admin_init', 'fontawesome_dashboard');

/*==============================================
=        		   ARCHIVE PAGES	  		    =
==============================================*/
// Removes the Archive Title Prefix. ("Archive:", "Foo:", "Bar:").
add_filter('get_the_archive_title', function ($title) {
    return preg_replace('/^\w+: /', '', $title);
});

/*==============================================
=        		  THEME UPDATES    		       =
= https://github.com/YahnisElsts/plugin-update-checker#self-hosted-plugins-and-themes =
==============================================*/
require get_template_directory() . '/plugin-update-checker/plugin-update-checker.php';
use YahnisElsts\PluginUpdateChecker\v5\PucFactory;

$myUpdateChecker = PucFactory::buildUpdateChecker(
	'https://bygreg.net/wp-content/themes/kin/info.json',
	__FILE__, //Full path to the main plugin file or functions.php.
	'unique-plugin-or-theme-slug'
);
	

/*==============================================
=           	FUNCTION.PHP CHILD             =
==============================================*/

if( class_exists('ACF') ) {
	$functionChild = get_template_directory() . '/template-parts/'. get_field('template', 'option') . '/function.php';
	if(file_exists($functionChild)){
		include($functionChild);
	}
}